@@ -394,6 +394,31 @@ void tst_qmlls_modules::buildDir()
                                    QStringList({ u"QtQuick"_s, u"vector4d"_s })));
 }
 
+void tst_qmlls_modules::inMemoryEnumCompletion()
+{
+    ignoreDiagnostics();
+    const QString filePath = u"completions/SimpleItem.qml"_s;
+    const auto uri = openFile(filePath);
+    QVERIFY(uri);
+
+    // add in memory enum that does not exist on disk
+    TextDocumentContentChangeEvent change;
+    change.range = Range{ Position{ 3, 0 }, Position{ 3, 0 } };
+    change.text = "enum HelloEnum { Hello, World, Kitty, Qt }\nproperty var myP: SimpleItem.H";
+
+    DidChangeTextDocumentParams didChange;
+    didChange.textDocument.uri = *uri;
+    didChange.textDocument.version = 2;
+    didChange.contentChanges.append(change);
+    m_protocol->notifyDidChangeTextDocument(didChange);
+
+    QTEST_CHECKED(checkCompletions(*uri, 4, 29,
+                                   ExpectedCompletions({
+                                           { u"Hello"_s, CompletionItemKind::EnumMember },
+                                   }),
+                                   QStringList({ u"QtQuick"_s, u"vector4d"_s })));
+}
+
 void tst_qmlls_modules::automaticSemicolonInsertionForCompletions_data()
 {
     QTest::addColumn<QString>("filePath");
@@ -654,9 +679,12 @@ void tst_qmlls_modules::findUsages_data()
 
     // line and character start at 1!
     const QList<QLspSpecification::Location> sumUsages = {
-        locationFrom(jsIdentifierUsagesUri, jsIdentifierUsagesContent, 8, 13, strlen("sum")),
-        locationFrom(jsIdentifierUsagesUri, jsIdentifierUsagesContent, 10, 13, strlen("sum")),
-        locationFrom(jsIdentifierUsagesUri, jsIdentifierUsagesContent, 10, 19, strlen("sum")),
+        locationFrom(jsIdentifierUsagesUri, jsIdentifierUsagesContent, 8, 13,
+                     static_cast<quint32>(strlen("sum"))),
+        locationFrom(jsIdentifierUsagesUri, jsIdentifierUsagesContent, 10, 13,
+                     static_cast<quint32>(strlen("sum"))),
+        locationFrom(jsIdentifierUsagesUri, jsIdentifierUsagesContent, 10, 19,
+                     static_cast<quint32>(strlen("sum"))),
     };
     QVERIFY(sumUsages.front().uri.startsWith("file://"_ba));
 
@@ -910,13 +938,16 @@ void tst_qmlls_modules::renameUsages_data()
                         OptionalVersionedTextDocumentIdentifier{ { jsIdentifierUsagesUri } },
                         {
                                 TextEdit{
-                                        rangeFrom(jsIdentifierUsagesContent, 8, 13, strlen("sum")),
+                                        rangeFrom(jsIdentifierUsagesContent, 8, 13,
+                                                  static_cast<quint32>(strlen("sum"))),
                                         "specialSum" },
                                 TextEdit{
-                                        rangeFrom(jsIdentifierUsagesContent, 10, 13, strlen("sum")),
+                                        rangeFrom(jsIdentifierUsagesContent, 10, 13,
+                                                  static_cast<quint32>(strlen("sum"))),
                                         "specialSum" },
                                 TextEdit{
-                                        rangeFrom(jsIdentifierUsagesContent, 10, 19, strlen("sum")),
+                                        rangeFrom(jsIdentifierUsagesContent, 10, 19,
+                                                  static_cast<quint32>(strlen("sum"))),
                                         "specialSum" },
                         } },
         }
@@ -954,7 +985,7 @@ void tst_qmlls_modules::renameUsages_data()
                             OptionalVersionedTextDocumentIdentifier{ { renameUsagesUri } },
                             {
                                     TextEdit{ rangeFrom(renamingContent, 4, 5,
-                                                        strlen("RenameMe")),
+                                                        static_cast<quint32>(strlen("RenameMe"))),
                                               "HelloWorld" },
                             } },
                     RenameFile{ "rename", renameMeUri, newFileUri } }
@@ -972,7 +1003,7 @@ void tst_qmlls_modules::renameUsages_data()
                             OptionalVersionedTextDocumentIdentifier{ { renameUsagesUri } },
                             {
                                     TextEdit{ rangeFrom(renamingContent, 5, 5,
-                                                        strlen("RenameMe2")),
+                                                        static_cast<quint32>(strlen("RenameMe2"))),
                                               "HelloWorld" },
                             } },
                     RenameFile{ "rename", renameMe2Uri, newFileUri2 } }
@@ -1152,7 +1183,7 @@ struct EditingRecorder
 
 static constexpr int characterAfter(const char *line)
 {
-    return std::char_traits<char>::length(line) + 1;
+    return static_cast<int>(std::char_traits<char>::length(line) + 1);
 }
 
 static EditingRecorder propertyTypoScenario(const QByteArray &fileUri)
@@ -1190,6 +1221,23 @@ static EditingRecorder propertyTypoScenario(const QByteArray &fileUri)
     return propertyTypo;
 }
 
+static EditingRecorder inMemoryEnumScenario(const QByteArray &fileUri)
+{
+    EditingRecorder scenario;
+    scenario.lastFileUri = fileUri;
+
+    const QString enumWithTypo =
+            u"enum Hello { World, Qt, Kitty }\nproperty var xxx: SimpleItem.Q"_s;
+    // expect an error because of the missing "t"
+    scenario.changeText(5, 1, 5, 1, enumWithTypo);
+    scenario.setCurrentExpectedDiagnostic("Member \"Q\" not found");
+
+    // fix the typo and expect no more error, despite the enum not existing on the file on disk
+    scenario.changeText(6, 31, 6, 31, u"t"_s);
+
+    return scenario;
+}
+
 void tst_qmlls_modules::linting_data()
 {
     QTest::addColumn<QString>("filePath");
@@ -1198,6 +1246,10 @@ void tst_qmlls_modules::linting_data()
     QTest::addRow("property-typo")
             << u"linting/SimpleItem.qml"_s
             << propertyTypoScenario(testFileUrl(u"linting/SimpleItem.qml"_s).toEncoded());
+
+    QTest::addRow("in-memory-enum")
+            << u"linting/SimpleItem.qml"_s
+            << inMemoryEnumScenario(testFileUrl(u"linting/SimpleItem.qml"_s).toEncoded());
 }
 
 void tst_qmlls_modules::linting()
